import os


basedir = os.path.abspath(os.path.dirname(__file__))


class Config:
    MAIL_SERVER = os.environ.get('MAIL_SERVER')
    MAIL_PORT = int(os.environ.get('MAIL_PORT'))
    MAIL_USE_TLS = os.environ.get('MAIL_USE_TLS').lower() == 'true'
    MAIL_USERNAME = os.environ.get('MAIL_USERNAME')
    MAIL_PASSWORD = os.environ.get('MAIL_PASSWORD')
    OPAQUE_ADMIN = os.environ.get('OPAQUE_ADMIN')
    OPAQUE_STORAGE = os.environ.get('OPAQUE_STORAGE')
    OPAQUE_MAIL_SUBJECT_PREFIX = '[Opaque]'
    OPAQUE_MAIL_SENDER = 'Opaque'
    SECRET_KEY = os.environ.get('SECRET_KEY') or 'hard to guess string'
    SQLALCHEMY_TRACK_MODIFICATIONS = False

    @staticmethod
    def init_app(app):
        pass


class DevelopmentConfig(Config):
    DEBUG = True
    # SQLALCHEMY_DATABASE_URI = 'sqlite:///' + os.path.join(basedir,
    #                                                       'data_dev.sqlite')
    SQLALCHEMY_DATABASE_URI = \
        'postgresql+psycopg2://{user}:{passwd}@{host}:{port}/{db}'.format(
            user=os.environ.get('POSTGRES_USER'),
            passwd=os.environ.get('POSTGRES_PASSWORD'),
            host=os.environ.get('POSTGRES_HOST'),
            port=os.environ.get('POSTGRES_PORT'),
            db=os.environ.get('POSTGRES_DB_NAME'))
    print(SQLALCHEMY_DATABASE_URI)


class TestingConfig(Config):
    TESTING = True
    SQLALCHEMY_DATABASE_URI = os.environ.get('TEST_DATABASE_URL') or \
        'sqlite://'
    WTF_CSRF_ENABLED = False


# class ProductionConfig(Config):


config = {
    'development': DevelopmentConfig,
    'testing': TestingConfig,
    #'production': ProductionConfig,

    'default': DevelopmentConfig
}
